From 71ea2a179a8ef82f990ed08d689d878bdf024e2b Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Wed, 04 Jan 2012 10:15:19 -0500
Subject: [PATCH] - Fixed: FS#1936 - date(): It is not safe to rely on the system's timezone settings. - Added a timezone setting in config.inc.ohp file
---
install/install.php | 3 ++-
1 files changed, 2 insertions(+), 1 deletions(-)
diff --git a/install/install.php b/install/install.php
index a31efbc..78a5fb3 100644
--- a/install/install.php
+++ b/install/install.php
@@ -102,8 +102,9 @@
//** Detect the installed applications
$inst->find_installed_apps();
//** Select the language
$conf['language'] = $inst->simple_query('Select language', array('en','de'), 'en');
+$conf['timezone'] = 'UTC';
//** Select installation mode
$install_mode = $inst->simple_query('Installation mode', array('standard','expert'), 'standard');
@@ -102,8 +102,9 @@
//** Detect the installed applications
$inst->find_installed_apps();
-//** Select the language
+//** Select the language and set default timezone
$conf['language'] = $inst->simple_query('Select language', array('en','de'), 'en');
--
Gitblit v1.9.1